﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;

public class ShipControl : MonoBehaviour
{
    public GameObject shield; // Reference to the shield GameObject
    public GameManager gameManager;
    public GameObject bulletPrefab;
    public GameObject explosionPrefab;
    public GameObject MissilePrefab;
    public float speed = 5f;
    public float xLimit = 7f;
    public float yLimit = 5f;
    public float reloadTime = 0.4f;
    public int playerHealth = 4;
    private float elapsedTime = 0f;
    public int reloadBulletsFired = 10;
    public Text shieldText;
    

    public AudioClip destructionClip;
    private AudioSource audioSource;

    void Start()
    {
        // Ensure the shield is disabled at the start
        if (shield != null)
        {
            shield.SetActive(true);
        }
    }

    void Update()
    {
        // Keeping track of time for bullet firing
        elapsedTime += Time.deltaTime;

        // Move the player using vertical and horizontal input
        float verticalInput = Input.GetAxis("Vertical");
        float horizontalInput = Input.GetAxis("Horizontal");

        // Move and clamp the ship's position
        Vector3 movement = new Vector3(horizontalInput, verticalInput, 0) * speed * Time.deltaTime;
        transform.Translate(movement);

        // Clamp x and y positions
        Vector3 position = transform.position;
        position.x = Mathf.Clamp(position.x, -xLimit, xLimit);
        position.y = Mathf.Clamp(position.y, -yLimit, yLimit);
        transform.position = position;

       

        // Fire bullets if enough time has elapsed since last firing
        if (Input.GetButton("Jump") && elapsedTime > reloadTime)
        {
            FireBullets();
            elapsedTime = 0f;
        }
        if (Input.GetButtonDown("Fire1") && reloadBulletsFired != 0)
        {
            FireMissile();
            elapsedTime = 0f;
            --reloadBulletsFired;
            print(reloadBulletsFired);
        }
    }

    void FireMissile()
    {
        Vector3 bulletDirection = transform.up;
        Vector3 spawnPos1 = transform.position + bulletDirection * 1.2f;
        Instantiate(MissilePrefab, spawnPos1, Quaternion.Euler(0, 0, transform.rotation.eulerAngles.z));
    }

    void FireBullets()
    {
        Vector3 bulletDirection = transform.up;
        Vector3 spawnPos1 = transform.position + bulletDirection * 1.2f + new Vector3(0.3f, 0, 0);
        Vector3 spawnPos2 = transform.position + bulletDirection * 1.2f + new Vector3(-0.3f, 0, 0);

        Instantiate(bulletPrefab, spawnPos1, Quaternion.Euler(0, 0, transform.rotation.eulerAngles.z));
        Instantiate(bulletPrefab, spawnPos2, Quaternion.Euler(0, 0, transform.rotation.eulerAngles.z));
    }

    void OnTriggerEnter2D(Collider2D other)
    {
        playerHealth--;
        Destroy(other.gameObject);
        if (playerHealth <= 0)
        {
            Vector3 spawnPosEx = transform.position;
            Instantiate(explosionPrefab, spawnPosEx, Quaternion.Euler(0, 0, transform.rotation.eulerAngles.z));
            gameManager.PlayerDied();
        }
        else
        {
            HandleShieldActivation();
            HandleShipDestruction();
        }
    }

    void HandleShieldActivation()
    {
        //if (playerHealth == 3 && shield != null)
        //{
        //    shield.SetActive(true); // Activate the shield
        //}
        if (playerHealth < 2 && shield != null)
        {
            shield.SetActive(false); // Deactivate the shield
        }
    }

    void HandleShipDestruction()
    {
        if (playerHealth == 3)
        {
            
            shieldText.text = "Shields are Damaged";
            shieldText.color = Color.yellow;
        }
        else if (playerHealth == 2)
        {
            
            shieldText.text = "Shields are Critical";
            shieldText.color = Color.red;
        }
        else if (playerHealth == 1)
        {
            
            shieldText.text = "Shields are Gone";
        }
    }
}



